Downloader class

Constructors

Downloader(String url, {int chunkSize = 501001, int p = 2, String? savePath})
factory

Properties

client HttpClient
getter/setter pair
controller StreamController<ProcessState>?
getter/setter pair
downloadUrl String
getter/setter pair
fetching bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
noError bool
getter/setter pair
processors int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savePath String?
getter/setter pair
state ProcessState
getter/setter pair

Methods

downChunk(ProcessState state, int idx, {int retry = 3}) Future<ProcessState>
download({OnPercentage? onPercentage}) Future<ProcessState>
downStream() Future<Stream<ProcessState>>
markFinished() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processor(ProcessState state, int pid, int pcount) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited