ProcessState class

Constructors

ProcessState(String url, {int chunkSize = 0, String? savePath})

Properties

chunks List<Chunk>
getter/setter pair
fileSize int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savePath String?
getter/setter pair
successCount int
getter/setter pair
url String
getter/setter pair

Methods

asList() Uint8List
init(int size) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited